@@ -1,10 +1,12 @@
+from ._constants import AlbumSortOrder
 from ._version import __version__
-from .photoinfo import PhotoInfo
+from .exiftool import ExifTool
+from .photoinfo import ExportResults, PhotoInfo
 from .photosdb import PhotosDB
 from .photosdb._photosdb_process_comments import CommentInfo, LikeInfo
 from .phototemplate import PhotoTemplate
+from .queryoptions import QueryOptions
 from .utils import _debug, _get_logger, _set_debug
 
 # TODO: Add test for imageTimeZoneOffsetSeconds = None
-# TODO: Add test for __str__ and to_json
 # TODO: Add special albums and magic albums
