@@ -30,6 +30,8 @@ _TESTED_DB_VERSIONS = ["6000", "4025", "4016", "3301", "2622"]
 # Photos 6 (10.16.0 Beta) == 14104
 _TEST_MODEL_VERSIONS = ["13537", "13703", "14104"]
 
+_PHOTOS_2_VERSION = "2622"
+
 # only version 3 - 4 have RKVersion.selfPortrait
 _PHOTOS_3_VERSION = "3301"
 
@@ -94,6 +96,8 @@ _TESTED_OS_VERSIONS = [
     ("11", "2"),
     ("11", "3"),
     ("11", "4"),
+    ("11", "5"),
+    ("11", "6"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -119,12 +123,20 @@ _XMP_TEMPLATE_NAME_BETA = "xmp_sidecar_beta.mako"
 # Constants used for processing folders and albums
 _PHOTOS_5_ALBUM_KIND = 2  # normal user album
 _PHOTOS_5_SHARED_ALBUM_KIND = 1505  # shared album
+_PHOTOS_5_PROJECT_ALBUM_KIND = 1508  # My Projects (e.g. Calendar, Card, Slideshow)
 _PHOTOS_5_FOLDER_KIND = 4000  # user folder
 _PHOTOS_5_ROOT_FOLDER_KIND = 3999  # root folder
 _PHOTOS_5_IMPORT_SESSION_ALBUM_KIND = 1506  # import session
 
 _PHOTOS_4_ALBUM_KIND = 3  # RKAlbum.albumSubclass
-_PHOTOS_4_TOP_LEVEL_ALBUM = "TopLevelAlbums"
+_PHOTOS_4_ALBUM_TYPE_ALBUM = 1  # RKAlbum.albumType
+_PHOTOS_4_ALBUM_TYPE_PROJECT = 9  # RKAlbum.albumType
+_PHOTOS_4_ALBUM_TYPE_SLIDESHOW = 8  # RKAlbum.albumType
+_PHOTOS_4_TOP_LEVEL_ALBUMS = [
+    "TopLevelAlbums",
+    "TopLevelKeepsakes",
+    "TopLevelSlideshows",
+]
 _PHOTOS_4_ROOT_FOLDER = "LibraryFolder"
 
 # EXIF related constants
@@ -275,12 +287,15 @@ POST_COMMAND_CATEGORIES = {
     # "deleted_directories": "When used with '--cleanup', all directories deleted during the export",
 }
 
+
 class AlbumSortOrder(Enum):
     """Album Sort Order"""
+
     UNKNOWN = 0
     MANUAL = 1
     NEWEST_FIRST = 2
     OLDEST_FIRST = 3
     TITLE = 5
 
-TEXT_DETECTION_CONFIDENCE_THRESHOLD = 0.75
\ No newline at end of file
+
+TEXT_DETECTION_CONFIDENCE_THRESHOLD = 0.75
