@@ -14,7 +14,7 @@ from datetime import datetime, timedelta, timezone
 
 from ._constants import (
     _PHOTOS_4_ALBUM_KIND,
-    _PHOTOS_4_TOP_LEVEL_ALBUM,
+    _PHOTOS_4_TOP_LEVEL_ALBUMS,
     _PHOTOS_4_VERSION,
     _PHOTOS_5_ALBUM_KIND,
     _PHOTOS_5_FOLDER_KIND,
@@ -22,6 +22,7 @@ from ._constants import (
     AlbumSortOrder,
 )
 from .datetime_utils import get_local_tz
+from .query_builder import get_query
 
 
 def sort_list_by_keys(values, sort_keys):
@@ -131,6 +132,28 @@ class AlbumInfoBaseClass:
     def photos(self):
         return []
 
+    @property
+    def owner(self):
+        """Return name of photo owner for shared album (Photos 5+ only), or None if not shared"""
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return None
+
+        try:
+            return self._owner
+        except AttributeError:
+            try:
+                personid = self._db._dbalbum_details[self.uuid][
+                    "cloudownerhashedpersonid"
+                ]
+                self._owner = (
+                    self._db._db_hashed_person_id[personid]["full_name"]
+                    if personid
+                    else None
+                )
+            except KeyError:
+                self._owner = None
+            return self._owner
+
     def __len__(self):
         """return number of photos contained in album"""
         return len(self.photos)
@@ -138,7 +161,6 @@ class AlbumInfoBaseClass:
 
 class AlbumInfo(AlbumInfoBaseClass):
     """
-    Base class for AlbumInfo, ImportInfo
     Info about a specific Album, contains all the details about the album
     including folders, photos, etc.
     """
@@ -208,7 +230,7 @@ class AlbumInfo(AlbumInfoBaseClass):
                 parent_uuid = self._db._dbalbum_details[self._uuid]["folderUuid"]
                 self._parent = (
                     FolderInfo(db=self._db, uuid=parent_uuid)
-                    if parent_uuid != _PHOTOS_4_TOP_LEVEL_ALBUM
+                    if parent_uuid not in _PHOTOS_4_TOP_LEVEL_ALBUMS
                     else None
                 )
             else:
@@ -243,18 +265,17 @@ class AlbumInfo(AlbumInfoBaseClass):
 
     def photo_index(self, photo):
         """return index of photo in album (based on album sort order)"""
-        index = 0
-        for p in self.photos:
+        for index, p in enumerate(self.photos):
             if p.uuid == photo.uuid:
                 return index
-            index += 1
-        else:
-            raise ValueError(
-                f"Photo with uuid {photo.uuid} does not appear to be in this album"
-            )
+        raise ValueError(
+            f"Photo with uuid {photo.uuid} does not appear to be in this album"
+        )
 
 
 class ImportInfo(AlbumInfoBaseClass):
+    """Information about import sessions"""
+
     @property
     def photos(self):
         """return list of photos contained in import session"""
@@ -273,6 +294,15 @@ class ImportInfo(AlbumInfoBaseClass):
             return self._photos
 
 
+class ProjectInfo(AlbumInfo):
+    """
+    ProjectInfo with info about projects
+    Projects are cards, calendars, slideshows, etc.
+    """
+
+    ...
+
+
 class FolderInfo:
     """
     Info about a specific folder, contains all the details about the folder
@@ -334,7 +364,7 @@ class FolderInfo:
                 parent_uuid = self._db._dbfolder_details[self._uuid]["parentFolderUuid"]
                 self._parent = (
                     FolderInfo(db=self._db, uuid=parent_uuid)
-                    if parent_uuid != _PHOTOS_4_TOP_LEVEL_ALBUM
+                    if parent_uuid not in _PHOTOS_4_TOP_LEVEL_ALBUMS
                     else None
                 )
             else:
