@@ -7,4 +7,4 @@ PhotosDB.photos() returns a list of PhotoInfo objects
 from ._photoinfo_exifinfo import ExifInfo
 from ._photoinfo_export import ExportResults
 from ._photoinfo_scoreinfo import ScoreInfo
-from .photoinfo import PhotoInfo
+from .photoinfo import PhotoInfo, PhotoInfoNone
\ No newline at end of file
