@@ -56,7 +56,7 @@ from ..photokit import (
 )
 from ..phototemplate import RenderOptions
 from ..uti import get_preferred_uti_extension
-from ..utils import findfiles, lineno, noop
+from ..utils import increment_filename, increment_filename_with_count, lineno
 
 # retry if use_photos_export fails the first time (which sometimes it does)
 MAX_PHOTOSCRIPT_RETRIES = 3
@@ -280,7 +280,7 @@ def _export_photo_uuid_applescript(
 
     if not exported_files or not filename:
         # nothing got exported
-        raise ExportError(f"Could not export photo {uuid}")
+        raise ExportError(f"Could not export photo {uuid} ({lineno(__file__)})")
 
     # need to find actual filename as sometimes Photos renames JPG to jpeg on export
     # may be more than one file exported (e.g. if Live Photo, Photos exports both .jpeg and .mov)
@@ -530,6 +530,7 @@ def export2(
     preview=False,
     preview_suffix=DEFAULT_PREVIEW_SUFFIX,
     render_options: Optional[RenderOptions] = None,
+    strip=False,
 ):
     """export photo, like export but with update and dry_run options
     dest: must be valid destination path or exception raised
@@ -588,6 +589,7 @@ def export2(
     preview: if True, also exports preview image
     preview_suffix: optional string to append to end of filename for preview images
     render_options: optional osxphotos.phototemplate.RenderOptions instance to specify options for rendering templates
+    strip: if True, strip whitespace from rendered templates
 
     Returns: ExportResults class
         ExportResults has attributes:
@@ -681,15 +683,12 @@ def export2(
     # e.g. exporting sidecar for file1.png and file1.jpeg
     # if file1.png exists and exporting file1.jpeg,
     # dest will be file1 (1).jpeg even though file1.jpeg doesn't exist to prevent sidecar collision
-    count = 0
-    if not update and increment and not overwrite:
-        dest_files = findfiles(f"{dest_original.stem}*", str(dest_original.parent))
-        dest_files = [pathlib.Path(f).stem.lower() for f in dest_files]
-        dest_new = dest_original.stem
-        while dest_new.lower() in dest_files:
-            count += 1
-            dest_new = f"{dest_original.stem} ({count})"
-        dest_original = dest_original.parent / f"{dest_new}{dest_original.suffix}"
+    increment_file_count = 0
+    if increment and not update and not overwrite:
+        dest_original, increment_file_count = increment_filename_with_count(
+            dest_original
+        )
+        dest_original = pathlib.Path(dest_original)
 
     # if overwrite==False and #increment==False, export should fail if file exists
     if (
@@ -704,17 +703,11 @@ def export2(
         )
 
     if export_edited:
-        if not update and increment and not overwrite:
-            dest_files = findfiles(f"{dest_edited.stem}*", str(dest_edited.parent))
-            dest_files = [pathlib.Path(f).stem.lower() for f in dest_files]
-            dest_new = dest_edited.stem
-            if count:
-                # incremented above when checking original destination
-                dest_new = f"{dest_new} ({count})"
-            while dest_new.lower() in dest_files:
-                count += 1
-                dest_new = f"{dest.stem} ({count})"
-            dest_edited = dest_edited.parent / f"{dest_new}{dest_edited.suffix}"
+        if increment and not update and not overwrite:
+            dest_edited, increment_file_count = increment_filename_with_count(
+                dest_edited, increment_file_count
+            )
+            dest_edited = pathlib.Path(dest_edited)
 
         # if overwrite==False and #increment==False, export should fail if file exists
         if dest_edited.exists() and not update and not overwrite and not increment:
@@ -798,20 +791,16 @@ def export2(
                     )
                 if dest_uuid != self.uuid:
                     # not the right file, find the right one
-                    count = 1
                     glob_str = str(dest.parent / f"{dest.stem} (*{dest.suffix}")
                     dest_files = glob.glob(glob_str)
-                    found_match = False
                     for file_ in dest_files:
                         dest_uuid = export_db.get_uuid_for_file(file_)
                         if dest_uuid == self.uuid:
                             dest = pathlib.Path(file_)
-                            found_match = True
                             break
                         elif dest_uuid is None and fileutil.cmp(src, file_):
                             # files match, update the UUID
                             dest = pathlib.Path(file_)
-                            found_match = True
                             export_db.set_data(
                                 filename=dest,
                                 uuid=self.uuid,
@@ -823,18 +812,14 @@ def export2(
                                 exif_json=None,
                             )
                             break
-
-                    if not found_match:
+                    else:
                         # increment the destination file
-                        count = 1
-                        glob_str = str(dest.parent / f"{dest.stem}*")
-                        dest_files = glob.glob(glob_str)
-                        dest_files = [pathlib.Path(f).stem for f in dest_files]
-                        dest_new = dest.stem
-                        while dest_new in dest_files:
-                            dest_new = f"{dest.stem} ({count})"
-                            count += 1
-                        dest = dest.parent / f"{dest_new}{dest.suffix}"
+                        dest = pathlib.Path(increment_filename(dest))
+
+            if export_original:
+                dest_original = dest
+            else:
+                dest_edited = dest
 
             # export the dest file
             results = self._export_photo(
@@ -927,6 +912,14 @@ def export2(
             preview_path = pathlib.Path(self.path_derivatives[0])
             preview_ext = preview_path.suffix
             preview_name = dest.parent / f"{dest.stem}{preview_suffix}{preview_ext}"
+            # if original is missing, the filename won't have been incremented so
+            # need to check here to make sure there aren't duplicate preview files in
+            # the export directory
+            preview_name = (
+                preview_name
+                if overwrite or update
+                else pathlib.Path(increment_filename(preview_name))
+            )
             if preview_path is not None:
                 results = self._export_photo(
                     preview_path,
@@ -969,6 +962,7 @@ def export2(
             persons=persons,
             location=location,
             replace_keywords=replace_keywords,
+            strip=strip,
         )
         sidecars.append(
             (
@@ -995,6 +989,7 @@ def export2(
             persons=persons,
             location=location,
             replace_keywords=replace_keywords,
+            strip=strip,
         )
         sidecars.append(
             (
@@ -1017,6 +1012,7 @@ def export2(
             persons=persons,
             location=location,
             replace_keywords=replace_keywords,
+            strip=strip,
         )
         sidecars.append(
             (
@@ -1087,6 +1083,7 @@ def export2(
                         persons=persons,
                         location=location,
                         replace_keywords=replace_keywords,
+                        strip=strip,
                     )
                 )[0]
                 if old_data != current_data:
@@ -1110,6 +1107,7 @@ def export2(
                         persons=persons,
                         location=location,
                         replace_keywords=replace_keywords,
+                        strip=strip,
                     )
                     if warning_:
                         all_results.exiftool_warning.append((exported_file, warning_))
@@ -1130,6 +1128,7 @@ def export2(
                         persons=persons,
                         location=location,
                         replace_keywords=replace_keywords,
+                        strip=strip,
                     ),
                 )
                 export_db.set_stat_exif_for_file(
@@ -1155,6 +1154,7 @@ def export2(
                     persons=persons,
                     location=location,
                     replace_keywords=replace_keywords,
+                    strip=strip,
                 )
                 if warning_:
                     all_results.exiftool_warning.append((exported_file, warning_))
@@ -1175,6 +1175,7 @@ def export2(
                     persons=persons,
                     location=location,
                     replace_keywords=replace_keywords,
+                    strip=strip,
                 ),
             )
             export_db.set_stat_exif_for_file(
@@ -1265,6 +1266,7 @@ def _export_photo_with_photos_export(
                             dest.name,
                             version=PHOTOS_VERSION_CURRENT,
                             overwrite=overwrite,
+                            video=live_photo,
                         )
                         all_results.exported.extend(exported)
                     except Exception as e:
@@ -1312,6 +1314,7 @@ def _export_photo_with_photos_export(
                             dest.name,
                             version=PHOTOS_VERSION_ORIGINAL,
                             overwrite=overwrite,
+                            video=live_photo,
                         )
                         all_results.exported.extend(exported)
                     except Exception as e:
@@ -1521,16 +1524,31 @@ def _export_photo(
         edited_stat = fileutil.file_sig(src) if edited else (None, None, None)
         if dest_exists and (update or overwrite):
             # need to remove the destination first
-            fileutil.unlink(dest)
+            try:
+                fileutil.unlink(dest)
+            except Exception as e:
+                raise ExportError(
+                    f"Error removing file {dest}: {e} (({lineno(__file__)})"
+                ) from e
         if export_as_hardlink:
-            fileutil.hardlink(src, dest)
+            try:
+                fileutil.hardlink(src, dest)
+            except Exception as e:
+                raise ExportError(
+                    f"Error hardlinking {src} to {dest}: {e} ({lineno(__file__)})"
+                ) from e
         elif convert_to_jpeg:
             # use convert_to_jpeg to export the file
             fileutil.convert_to_jpeg(src, dest_str, compression_quality=jpeg_quality)
             converted_stat = fileutil.file_sig(dest_str)
             converted_to_jpeg_files.append(dest_str)
         else:
-            fileutil.copy(src, dest_str)
+            try:
+                fileutil.copy(src, dest_str)
+            except Exception as e:
+                raise ExportError(
+                    f"Error copying file {src} to {dest_str}: {e} ({lineno(__file__)})"
+                ) from e
 
         export_db.set_data(
             filename=dest_str,
@@ -1580,6 +1598,7 @@ def _write_exif_data(
     persons=True,
     location=True,
     replace_keywords=False,
+    strip=False,
 ):
     """write exif data to image file at filepath
 
@@ -1593,6 +1612,7 @@ def _write_exif_data(
         persons: if True, write person data to metadata
         location: if True, write location data to metadata
         replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
+        strip: if True, strip any leading or trailing whitespace from rendered templates
 
     Returns:
         (warning, error) of warning and error strings if exiftool produces warnings or errors
@@ -1610,6 +1630,7 @@ def _write_exif_data(
         persons=persons,
         location=location,
         replace_keywords=replace_keywords,
+        strip=strip,
     )
 
     with ExifTool(filepath, flags=flags, exiftool=self._db._exiftool_path) as exiftool:
@@ -1635,6 +1656,7 @@ def _exiftool_dict(
     persons=True,
     location=True,
     replace_keywords=False,
+    strip=False,
 ):
     """Return dict of EXIF details for building exiftool JSON sidecar or sending commands to ExifTool.
         Does not include all the EXIF fields as those are likely already in the image.
@@ -1651,6 +1673,7 @@ def _exiftool_dict(
         persons: if True, include person data
         location: if True, include location data
         replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
+        strip: if True, strip any rendered templates
 
     Returns: dict with exiftool tags / values
 
@@ -1698,6 +1721,8 @@ def _exiftool_dict(
         )
         rendered = self.render_template(description_template, options)[0]
         description = " ".join(rendered) if rendered else ""
+        if strip:
+            description = description.strip()
         exif["EXIF:ImageDescription"] = description
         exif["XMP:Description"] = description
         exif["IPTC:Caption-Abstract"] = description
@@ -1745,6 +1770,9 @@ def _exiftool_dict(
                 )
             rendered_keywords.extend(rendered)
 
+        if strip:
+            rendered_keywords = [keyword.strip() for keyword in rendered_keywords]
+
         # filter out any template values that didn't match by looking for sentinel
         rendered_keywords = [
             keyword
@@ -1851,12 +1879,6 @@ def _exiftool_dict(
                 self.date_modified
             ).strftime("%Y:%m:%d %H:%M:%S")
 
-    # remove any new lines in any fields
-    for field, val in exif.items():
-        if type(val) == str:
-            exif[field] = val.replace("\n", " ")
-        elif type(val) == list:
-            exif[field] = [str(v).replace("\n", " ") for v in val if v is not None]
     return exif
 
 
@@ -1909,6 +1931,7 @@ def _exiftool_json_sidecar(
     persons=True,
     location=True,
     replace_keywords=False,
+    strip=False,
 ):
     """Return dict of EXIF details for building exiftool JSON sidecar or sending commands to ExifTool.
         Does not include all the EXIF fields as those are likely already in the image.
@@ -1926,6 +1949,7 @@ def _exiftool_json_sidecar(
         persons: if True, include person data
         location: if True, include location data
         replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
+        strip: if True, strip whitespace from rendered templates
 
     Returns: dict with exiftool tags / values
 
@@ -1965,6 +1989,7 @@ def _exiftool_json_sidecar(
         persons=persons,
         location=location,
         replace_keywords=replace_keywords,
+        strip=strip,
     )
 
     if not tag_groups:
@@ -1990,6 +2015,7 @@ def _xmp_sidecar(
     persons=True,
     location=True,
     replace_keywords=False,
+    strip=False,
 ):
     """returns string for XMP sidecar
     use_albums_as_keywords: treat album names as keywords
@@ -2002,6 +2028,7 @@ def _xmp_sidecar(
     persons: if True, include person data
     location: if True, include location data
     replace_keywords: if True, keyword_template replaces any keywords, otherwise it's additive
+    strip: if True, strip whitespace from rendered templates
     """
 
     xmp_template_file = (
@@ -2019,6 +2046,8 @@ def _xmp_sidecar(
         )
         rendered = self.render_template(description_template, options)[0]
         description = " ".join(rendered) if rendered else ""
+        if strip:
+            description = description.strip()
     else:
         description = self.description if self.description is not None else ""
 
@@ -2060,6 +2089,9 @@ def _xmp_sidecar(
                 )
             rendered_keywords.extend(rendered)
 
+        if strip:
+            rendered_keywords = [keyword.strip() for keyword in rendered_keywords]
+
         # filter out any template values that didn't match by looking for sentinel
         rendered_keywords = [
             keyword
