@@ -14,15 +14,20 @@ from datetime import timedelta, timezone
 from typing import Optional
 
 import yaml
+from osxmetadata import OSXMetaData
 
 from .._constants import (
     _MOVIE_TYPE,
     _PHOTO_TYPE,
     _PHOTOS_4_ALBUM_KIND,
+    _PHOTOS_4_ALBUM_TYPE_ALBUM,
+    _PHOTOS_4_ALBUM_TYPE_PROJECT,
+    _PHOTOS_4_ALBUM_TYPE_SLIDESHOW,
     _PHOTOS_4_ROOT_FOLDER,
     _PHOTOS_4_VERSION,
     _PHOTOS_5_ALBUM_KIND,
     _PHOTOS_5_IMPORT_SESSION_ALBUM_KIND,
+    _PHOTOS_5_PROJECT_ALBUM_KIND,
     _PHOTOS_5_SHARED_ALBUM_KIND,
     _PHOTOS_5_SHARED_PHOTO_PATH,
     _PHOTOS_5_VERSION,
@@ -33,10 +38,12 @@ from .._constants import (
     TEXT_DETECTION_CONFIDENCE_THRESHOLD,
 )
 from ..adjustmentsinfo import AdjustmentsInfo
-from ..albuminfo import AlbumInfo, ImportInfo
+from ..albuminfo import AlbumInfo, ImportInfo, ProjectInfo
+from ..momentinfo import MomentInfo
 from ..personinfo import FaceInfo, PersonInfo
 from ..phototemplate import PhotoTemplate, RenderOptions
 from ..placeinfo import PlaceInfo4, PlaceInfo5
+from ..query_builder import get_query
 from ..text_detection import detect_text
 from ..uti import get_preferred_uti_extension, get_uti_for_extension
 from ..utils import _debug, _get_resource_loc, findfiles
@@ -492,6 +499,18 @@ class PhotoInfo:
                 self._faceinfo = []
             return self._faceinfo
 
+    @property
+    def moment(self):
+        """Moment photo belongs to"""
+        try:
+            return self._moment
+        except AttributeError:
+            try:
+                self._moment = MomentInfo(db=self._db, moment_pk=self._info["momentID"])
+            except ValueError:
+                self._moment = None
+            return self._moment
+
     @property
     def albums(self):
         """list of albums picture is contained in"""
@@ -555,6 +574,18 @@ class PhotoInfo:
             )
             return self._import_info
 
+    @property
+    def project_info(self):
+        """list of AlbumInfo objects representing projects for the photo or None if no projects"""
+        try:
+            return self._project_info
+        except AttributeError:
+            project_uuids = self._get_album_uuids(project=True)
+            self._project_info = [
+                ProjectInfo(db=self._db, uuid=album) for album in project_uuids
+            ]
+            return self._project_info
+
     @property
     def keywords(self):
         """list of keywords for picture"""
@@ -563,7 +594,12 @@ class PhotoInfo:
     @property
     def title(self):
         """name / title of picture"""
-        return self._info["name"]
+        # if user sets then deletes title, Photos sets it to empty string in DB instead of NULL
+        # in this case, return None so result is the same as if title had never been set (which returns NULL)
+        # issue #512
+        title = self._info["name"]
+        title = None if title == "" else title
+        return title
 
     @property
     def uuid(self):
@@ -836,7 +872,7 @@ class PhotoInfo:
         if self._db._db_version <= _PHOTOS_4_VERSION:
             if self.live_photo and not self.ismissing:
                 live_model_id = self._info["live_model_id"]
-                if live_model_id == None:
+                if live_model_id is None:
                     logging.debug(f"missing live_model_id: {self._uuid}")
                     photopath = None
                 else:
@@ -857,28 +893,20 @@ class PhotoInfo:
                         # photos 4 has "isOnDisk" column we could check
                         # or could do the actual check with "isfile"
                         # TODO: should this be a warning or debug?
-                        logging.debug(
-                            f"MISSING PATH: live photo path for UUID {self._uuid} should be at {photopath} but does not appear to exist"
-                        )
                         photopath = None
             else:
                 photopath = None
-        else:
-            # Photos 5
-            if self.live_photo and not self.ismissing:
-                filename = pathlib.Path(self.path)
-                photopath = filename.parent.joinpath(f"{filename.stem}_3.mov")
-                photopath = str(photopath)
-                if not os.path.isfile(photopath):
-                    # In testing, I've seen occasional missing movie for live photo
-                    # these appear to be valid -- e.g. video component not yet downloaded from iCloud
-                    # TODO: should this be a warning or debug?
-                    logging.debug(
-                        f"MISSING PATH: live photo path for UUID {self._uuid} should be at {photopath} but does not appear to exist"
-                    )
-                    photopath = None
-            else:
+        elif self.live_photo and self.path and not self.ismissing:
+            filename = pathlib.Path(self.path)
+            photopath = filename.parent.joinpath(f"{filename.stem}_3.mov")
+            photopath = str(photopath)
+            if not os.path.isfile(photopath):
+                # In testing, I've seen occasional missing movie for live photo
+                # these appear to be valid -- e.g. video component not yet downloaded from iCloud
+                # TODO: should this be a warning or debug?
                 photopath = None
+        else:
+            photopath = None
 
         return photopath
 
@@ -1048,15 +1076,15 @@ class PhotoInfo:
             return self._info["orientation"]
 
         # For Photos 5+, try to get the adjusted orientation
-        if self.hasadjustments:
-            if self.adjustments:
-                return self.adjustments.adj_orientation
-            else:
-                # can't reliably determine orientation for edited photo if adjustmentinfo not available
-                return 0
-        else:
+        if not self.hasadjustments:
             return self._info["orientation"]
 
+        if self.adjustments:
+            return self.adjustments.adj_orientation
+        else:
+            # can't reliably determine orientation for edited photo if adjustmentinfo not available
+            return 0
+
     @property
     def original_height(self):
         """returns height of the original photo version in pixels"""
@@ -1092,6 +1120,26 @@ class PhotoInfo:
             logging.warning(f"Did not find signature for {self.uuid} in _db_signatures")
         return duplicates
 
+    @property
+    def owner(self):
+        """Return name of photo owner for shared photos (Photos 5+ only), or None if not shared"""
+        if self._db._db_version <= _PHOTOS_4_VERSION:
+            return None
+
+        try:
+            return self._owner
+        except AttributeError:
+            try:
+                personid = self._info["cloudownerhashedpersonid"]
+                self._owner = (
+                    self._db._db_hashed_person_id[personid]["full_name"]
+                    if personid
+                    else None
+                )
+            except KeyError:
+                self._owner = None
+            return self._owner
+
     def render_template(
         self, template_str: str, options: Optional[RenderOptions] = None
     ):
@@ -1118,6 +1166,28 @@ class PhotoInfo:
 
         Returns: list of (detected text, confidence) tuples
         """
+
+        try:
+            return self._detected_text_cache[confidence_threshold]
+        except (AttributeError, KeyError) as e:
+            if isinstance(e, AttributeError):
+                self._detected_text_cache = {}
+
+            try:
+                detected_text = self._detected_text()
+            except Exception as e:
+                logging.warning(f"Error detecting text in photo {self.uuid}: {e}")
+                detected_text = []
+
+            self._detected_text_cache[confidence_threshold] = [
+                (text, confidence)
+                for text, confidence in detected_text
+                if confidence >= confidence_threshold
+            ]
+            return self._detected_text_cache[confidence_threshold]
+
+    def _detected_text(self):
+        """detect text in photo, either from cached extended attribute or by attempting text detection"""
         path = (
             self.path_edited if self.hasadjustments and self.path_edited else self.path
         )
@@ -1125,23 +1195,13 @@ class PhotoInfo:
         if not path:
             return []
 
-        try:
-            return self._detected_text[(path, confidence_threshold)]
-        except (AttributeError, KeyError) as e:
-            if isinstance(e, AttributeError):
-                self._detected_text = {}
-
-            try:
-                detected_text = detect_text(path)
-            except Exception as e:
-                detected_text = []
-
-            self._detected_text[(path, confidence_threshold)] = [
-                (text, confidence)
-                for text, confidence in detected_text
-                if confidence >= confidence_threshold
-            ]
-            return self._detected_text[(path, confidence_threshold)]
+        md = OSXMetaData(path)
+        detected_text = md.get_attribute("osxphotos_detected_text")
+        if detected_text is None:
+            orientation = self.orientation or None
+            detected_text = detect_text(path, orientation)
+            md.set_attribute("osxphotos_detected_text", detected_text)
+        return detected_text
 
     @property
     def _longitude(self):
@@ -1153,34 +1213,48 @@ class PhotoInfo:
         """Returns latitude, in degrees"""
         return self._info["latitude"]
 
-    def _get_album_uuids(self):
+    def _get_album_uuids(self, project=False):
         """Return list of album UUIDs this photo is found in
 
             Filters out albums in the trash and any special album types
 
+            if project is True, returns special "My Project" albums (e.g. cards, calendars, slideshows)
+
         Returns: list of album UUIDs
         """
         if self._db._db_version <= _PHOTOS_4_VERSION:
-            version4 = True
             album_kind = [_PHOTOS_4_ALBUM_KIND]
-        else:
-            version4 = False
-            album_kind = [_PHOTOS_5_SHARED_ALBUM_KIND, _PHOTOS_5_ALBUM_KIND]
+            album_type = (
+                [_PHOTOS_4_ALBUM_TYPE_PROJECT, _PHOTOS_4_ALBUM_TYPE_SLIDESHOW]
+                if project
+                else [_PHOTOS_4_ALBUM_TYPE_ALBUM]
+            )
+            album_list = []
+            for album in self._info["albums"]:
+                detail = self._db._dbalbum_details[album]
+                if (
+                    detail["kind"] in album_kind
+                    and detail["albumType"] in album_type
+                    and not detail["intrash"]
+                    and detail["folderUuid"] != _PHOTOS_4_ROOT_FOLDER
+                    # in Photos <= 4, special albums like "printAlbum" have kind _PHOTOS_4_ALBUM_KIND
+                    # but should not be listed here; they can be distinguished by looking
+                    # for folderUuid of _PHOTOS_4_ROOT_FOLDER as opposed to _PHOTOS_4_TOP_LEVEL_ALBUM
+                ):
+                    album_list.append(album)
+            return album_list
+
+        # Photos 5+
+        album_kind = (
+            [_PHOTOS_5_PROJECT_ALBUM_KIND]
+            if project
+            else [_PHOTOS_5_SHARED_ALBUM_KIND, _PHOTOS_5_ALBUM_KIND]
+        )
 
         album_list = []
         for album in self._info["albums"]:
             detail = self._db._dbalbum_details[album]
-            if (
-                detail["kind"] in album_kind
-                and not detail["intrash"]
-                and (
-                    not version4
-                    # in Photos <= 4, special albums like "printAlbum" have kind _PHOTOS_4_ALBUM_KIND
-                    # but should not be listed here; they can be distinguished by looking
-                    # for folderUuid of _PHOTOS_4_ROOT_FOLDER as opposed to _PHOTOS_4_TOP_LEVEL_ALBUM
-                    or (version4 and detail["folderUuid"] != _PHOTOS_4_ROOT_FOLDER)
-                )
-            ):
+            if detail["kind"] in album_kind and not detail["intrash"]:
                 album_list.append(album)
         return album_list
 
