@@ -1,8 +1,9 @@
-""" Custom template system for osxphotos, implements osxphotos template language (OTL) """
+""" Custom template system for osxphotos, implements metadata template language (MTL) """
 
 import datetime
 import json
 import locale
+import logging
 import os
 import pathlib
 import shlex
@@ -26,7 +27,7 @@ from .utils import expand_and_validate_filepath, load_function
 # ensure locale set to user's locale
 locale.setlocale(locale.LC_ALL, "")
 
-OTL_GRAMMAR_MODEL = str(pathlib.Path(__file__).parent / "phototemplate.tx")
+MTL_GRAMMAR_MODEL = str(pathlib.Path(__file__).parent / "phototemplate.tx")
 
 """TextX metamodel for osxphotos template language """
 
@@ -180,6 +181,9 @@ TEMPLATE_SUBSTITUTIONS_PATHLIB = {
 TEMPLATE_SUBSTITUTIONS_MULTI_VALUED = {
     "{album}": "Album(s) photo is contained in",
     "{folder_album}": "Folder path + album photo is contained in. e.g. 'Folder/Subfolder/Album' or just 'Album' if no enclosing folder",
+    "{project}": "Project(s) photo is contained in (such as greeting cards, calendars, slideshows)",
+    "{album_project}": "Album(s) and project(s) photo is contained in; treats projects as regular albums",
+    "{folder_album_project}": "Folder path + album (includes projects as albums) photo is contained in. e.g. 'Folder/Subfolder/Album' or just 'Album' if no enclosing folder",
     "{keyword}": "Keyword(s) assigned to photo",
     "{person}": "Person(s) / face(s) in a photo",
     "{label}": "Image categorization label associated with a photo (Photos 5+ only). "
@@ -205,8 +209,10 @@ TEMPLATE_SUBSTITUTIONS_MULTI_VALUED = {
     + "The results for each photo will be cached in the export database so that future exports with '--update' do not need to reprocess each photo. "
     + "You may pass a confidence threshold value between 0.0 and 1.0 after a colon as in '{detected_text:0.5}'; "
     + f"The default confidence threshold is {TEXT_DETECTION_CONFIDENCE_THRESHOLD}. "
+    + "'{detected_text}' works only on macOS Catalina (10.15) or later. "
     + "Note: this feature is not the same thing as Live Text in macOS Monterey, which osxphotos does not yet support.",
     "{shell_quote}": "Use in form '{shell_quote,TEMPLATE}'; quotes the rendered TEMPLATE value(s) for safe usage in the shell, e.g. My file.jpeg => 'My file.jpeg'; only adds quotes if needed.",
+    "{strip}": "Use in form '{strip,TEMPLATE}'; strips whitespace from begining and end of rendered TEMPLATE value(s).",
     "{function}": "Execute a python function from an external file and use return value as template substitution. "
     + "Use in format: {function:file.py::function_name} where 'file.py' is the name of the python file and 'function_name' is the name of the function to call. "
     + "The function will be passed the PhotoInfo object for the photo. "
@@ -321,7 +327,7 @@ class PhotoTemplateParser:
         if hasattr(self, "metamodel"):
             return
 
-        self.metamodel = metamodel_from_file(OTL_GRAMMAR_MODEL, skipws=False)
+        self.metamodel = metamodel_from_file(MTL_GRAMMAR_MODEL, skipws=False)
 
     def parse(self, template_statement):
         """Parse a template_statement string"""
@@ -572,7 +578,7 @@ class PhotoTemplate:
 
             if self.expand_inplace or delim is not None:
                 sep = delim if delim is not None else self.inplace_sep
-                vals = [sep.join(sorted(vals))]
+                vals = [sep.join(sorted(vals))] if vals else []
 
             for filter_ in filters:
                 vals = self.get_template_value_filter(filter_, vals)
@@ -1001,6 +1007,9 @@ class PhotoTemplate:
         elif self.dirname:
             value = sanitize_dirname(value)
 
+        # ensure no empty strings in value (see #512)
+        value = None if value == "" else value
+
         return [value]
 
     def get_template_value_pathlib(self, field):
@@ -1110,6 +1119,11 @@ class PhotoTemplate:
         values = []
         if field == "album":
             values = self.photo.burst_albums if self.photo.burst else self.photo.albums
+        elif field == "project":
+            values = [p.title for p in self.photo.project_info]
+        elif field == "album_project":
+            values = self.photo.burst_albums if self.photo.burst else self.photo.albums
+            values += [p.title for p in self.photo.project_info]
         elif field == "keyword":
             values = self.photo.keywords
         elif field == "person":
@@ -1120,13 +1134,15 @@ class PhotoTemplate:
             values = self.photo.labels
         elif field == "label_normalized":
             values = self.photo.labels_normalized
-        elif field == "folder_album":
+        elif field in ["folder_album", "folder_album_project"]:
             values = []
             # photos must be in an album to be in a folder
             if self.photo.burst:
                 album_info = self.photo.burst_album_info
             else:
                 album_info = self.photo.album_info
+            if field == "folder_album_project":
+                album_info += self.photo.project_info
             for album in album_info:
                 if album.folder_names:
                     # album in folder
@@ -1160,6 +1176,8 @@ class PhotoTemplate:
             )
         elif field == "shell_quote":
             values = [shlex.quote(v) for v in default if v]
+        elif field == "strip":
+            values = [v.strip() for v in default]
         elif field.startswith("photo"):
             # provide access to PhotoInfo object
             properties = field.split(".")
@@ -1185,7 +1203,7 @@ class PhotoTemplate:
             elif isinstance(obj, (str, int, float)):
                 values = [str(obj)]
             else:
-                values = [val for val in obj]
+                values = list(obj)
         elif field == "detected_text":
             values = _get_detected_text(self.photo, self.exportdb, confidence=subfield)
         else:
@@ -1194,7 +1212,7 @@ class PhotoTemplate:
         # sanitize directory names if needed, folder_album handled differently above
         if self.filename:
             values = [sanitize_pathpart(value) for value in values]
-        elif self.dirname and field != "folder_album":
+        elif self.dirname and field not in ["folder_album", "folder_album_project"]:
             # skip folder_album because it would have been handled above
             values = [sanitize_dirname(value) for value in values]
 
@@ -1443,22 +1461,8 @@ def _get_detected_text(photo, exportdb, confidence=TEXT_DETECTION_CONFIDENCE_THR
         else TEXT_DETECTION_CONFIDENCE_THRESHOLD
     )
 
-    detected_text = exportdb.get_detected_text_for_uuid(photo.uuid)
-    if detected_text:
-        detected_text = json.loads(detected_text)
-    else:
-        path = (
-            photo.path_edited
-            if photo.hasadjustments and photo.path_edited
-            else photo.path
-        )
-        path = path or photo.path_derivatives[0] if photo.path_derivatives else None
-        if not path:
-            detected_text = []
-        else:
-            try:
-                detected_text = detect_text(path)
-            except Exception as e:
-                detected_text = []
-        exportdb.set_detected_text_for_uuid(photo.uuid, json.dumps(detected_text))
+    # _detected_text caches the text detection results in an extended attribute
+    # so the first time this gets called is slow but repeated accesses are fast
+    detected_text = photo._detected_text()
+    exportdb.set_detected_text_for_uuid(photo.uuid, json.dumps(detected_text))
     return [text for text, conf in detected_text if conf >= confidence]
